Package 'rk.tidyr'

Title: An RKWard plugin package for data manipulation using the 'tidyr', 'dplyr' and 'tibble' libraries.
Description: An RKWard plugin package for data manipulation using the 'tidyr', 'dplyr' and 'tibble' libraries.
Authors: Alfonso Cano
Maintainer: Alfonso Cano <[email protected]>
License: GPL (>= 3)
Version: 0.0.3
Built: 2026-06-04 10:01:32 UTC
Source: https://github.com/AlfCano/rk.tidyr

Help Index